# Configures misc programs that have shared config values between
# machines. These are intended to be very simple, so if it becomes
# needed to do extra configuration for example, consider putting
# the affected programs in their own modules.

{ pkgs, ... }: {

  home.packages = (with pkgs; [
    eva
    hyperfine
    du-dust
    pijul
    python311Packages.deemix
  ]) ++ (import ../env.nix pkgs);

  # CLI for accessing my passwords
  programs.rbw = {
    enable = true;
    settings = {
      email = "me@riley.lgbt";
      base_url = "https://vault.steph.tools";
      pinentry = "curses";
    };
  };

  # It's like `top` but cooler
  programs.bottom.enable = true;

  programs.eza = {
    enable = true;
    extraOptions = [
      "--group-directories-first"
    ];
  };

  programs.direnv.enable = true;
  programs.skim.enable   = true;
  programs.zoxide.enable = true;

  programs.helix = {
    enable = true;
    settings = {
      theme = "monokai_pro_spectrum";
      editor.auto-pairs = false;
    };
  };

}
