{ pkgs, ... }: {

  boot.loader = {
    grub.enable = false;
    generic-extlinux-compatible.enable = true;
  };

  networking = {
    hostName = "cherry";
    interfaces.eth0.useDHCP = true;
  };

  services.openssh = {
    enable = true;
    settings.PasswordAuthentication = false;
  };

  nix = {
    # TODO: Set up strawberry as a substituter
    # TODO: Set up nixbuild.net
    # TODO: Figure out how to make it safe to use other machines as remote
    # builders.
    distributedBuilds = false;
    buildMachines = [];
  };

  documentation.enable = false;

  fileSystems."/" = {
    device = "/dev/disk/by-label/NIXOS_SD";
    fsType = "ext4";
  };

  system.stateVersion = "21.11";

  boot.kernelPackages = pkgs.linuxPackages_latest;

  # User for running the website service
  users.users."website" = {
    isSystemUser = true;
    group = "website";
  };
  users.groups."website" = {};

  environment.systemPackages = with pkgs; [
    vim
    git
  ] ++ (import ../../shared/env.nix pkgs);

  users.users."root" = {
    # Allow access to this server from all the machines
    openssh.authorizedKeys.keyFiles = [
      ../dev-lt-63/keys/riley.pub
      ../strawberry/keys/riley.pub
      ../lime/keys/riley.pub
    ];
  };

}